@@ -104,6 +104,8 @@ class ManagerTestCases(testtools.TestCase):
     def test_create_configuration_invalid_logical_disks(self,
                                                         get_all_details_mock):
 
+        drives = raid_constants.HPSSA_NO_DRIVES
+        get_all_details_mock.return_value = drives
         raid_info = {}
         self.assertRaises(exception.InvalidInputError,
                           manager.create_configuration,
@@ -114,6 +116,21 @@ class ManagerTestCases(testtools.TestCase):
                           manager.create_configuration,
                           raid_info)
 
+        no_drives = raid_constants.HPSSA_NO_DRIVES
+        get_all_details_mock.return_value = no_drives
+        raid_info = {'logical_disks': [
+                     {'size_gb': 50,
+                      'raid_level': '1',
+                      'controller': 'Smart Array P822 in Slot 0',
+                      'physical_disks': ["6I:1:5", "6I:1:6"]}]}
+        msg = ("Invalid Input: Unable to find controller named 'Smart Array "
+               "P822 in Slot 0'. The available controllers are "
+               "'Smart Array P822 in Slot 2'.")
+        ex = self.assertRaises(exception.InvalidInputError,
+                               manager.create_configuration,
+                               raid_info)
+        self.assertEqual(msg, str(ex))
+
     @mock.patch.object(objects.Controller, 'execute_cmd')
     def test_create_configuration_without_disk_input_succeeds(
             self, controller_exec_cmd_mock, get_all_details_mock):
@@ -167,10 +184,24 @@ class ManagerTestCases(testtools.TestCase):
                                 raid_info)
         self.assertIn("of size 50 GB and raid level 1", str(exc))
 
+    def test_create_configuration_hba_enabled(self, get_all_details_mock):
+        drives = raid_constants.HPSSA_HBA_MODE
+        get_all_details_mock.return_value = drives
+
+        raid_info = {'logical_disks': 'foo'}
+
+        msg = ("An error was encountered while doing hpssa configuration: None"
+               " of the available HPSSA controllers Smart Array P822 in "
+               "Slot 3 have RAID enabled")
+        ex = self.assertRaises(exception.HPSSAOperationError,
+                               manager.create_configuration,
+                               raid_info)
+        self.assertIn(msg, str(ex))
+
     @mock.patch.object(objects.Controller, 'execute_cmd')
     def test_create_configuration_share_physical_disks(
             self, controller_exec_cmd_mock, get_all_details_mock):
-        no_drives = raid_constants.HPSSA_NO_DRIVES_2_PHYSICAL_DISKS
+        no_drives = raid_constants.HPSSA_NO_DRIVES_3_PHYSICAL_DISKS
         one_drive = raid_constants.ONE_DRIVE_RAID_1
         two_drives = raid_constants.TWO_DRIVES_50GB_RAID1
         get_all_details_mock.side_effect = [no_drives, one_drive, two_drives]
@@ -180,7 +211,8 @@ class ManagerTestCases(testtools.TestCase):
             (None, None)]
         raid_info = {'logical_disks': [{'size_gb': 50,
                                         'share_physical_disks': True,
-                                        'raid_level': '1',
+                                        'number_of_physical_disks': 2,
+                                        'raid_level': '0',
                                         'disk_type': 'hdd'},
                                        {'size_gb': 50,
                                         'share_physical_disks': True,
@@ -199,10 +231,44 @@ class ManagerTestCases(testtools.TestCase):
             'create', 'type=logicaldrive', 'drives=5I:1:1,5I:1:2',
             'raid=1', 'size=51200', process_input='y')
         controller_exec_cmd_mock.assert_any_call(
-            'array', 'A', 'create', 'type=logicaldrive', 'raid=1', 'size=?',
+            'array', 'A', 'create', 'type=logicaldrive', 'raid=0', 'size=?',
             dont_transform_to_hpssa_exception=True)
         controller_exec_cmd_mock.assert_any_call(
-            'array', 'A', 'create', 'type=logicaldrive', 'raid=1',
+            'array', 'A', 'create', 'type=logicaldrive', 'raid=0',
+            'size=51200', process_input='y')
+
+    @mock.patch.object(objects.Controller, 'execute_cmd')
+    def test_create_configuration_share_nonshare_physical_disks(
+            self, controller_exec_cmd_mock, get_all_details_mock):
+        no_drives = raid_constants.HPSSA_NO_DRIVES_3_PHYSICAL_DISKS
+        one_drive = raid_constants.ONE_DRIVE_RAID_1
+        two_drives = raid_constants.TWO_DRIVES_50GB_RAID1
+        get_all_details_mock.side_effect = [no_drives, one_drive, two_drives]
+        controller_exec_cmd_mock.side_effect = [
+            (None, None),
+            (raid_constants.DRIVE_2_RAID_1_OKAY_TO_SHARE, None),
+            (None, None)]
+        raid_info = {'logical_disks': [{'size_gb': 50,
+                                        'raid_level': '1',
+                                        'disk_type': 'hdd'},
+                                       {'size_gb': 50,
+                                        'share_physical_disks': True,
+                                        'raid_level': '0',
+                                        'disk_type': 'hdd'}]}
+        raid_info = manager.create_configuration(raid_info)
+        ld1 = raid_info['logical_disks'][0]
+        ld2 = raid_info['logical_disks'][1]
+        self.assertEqual('Smart Array P822 in Slot 2', ld1['controller'])
+        self.assertEqual('Smart Array P822 in Slot 2', ld2['controller'])
+        self.assertEqual(sorted(['5I:1:1', '5I:1:2']),
+                         sorted(ld1['physical_disks']))
+        self.assertEqual(sorted(['5I:1:1', '5I:1:2']),
+                         sorted(ld2['physical_disks']))
+        controller_exec_cmd_mock.assert_any_call(
+            'create', 'type=logicaldrive', 'drives=5I:1:1,5I:1:2',
+            'raid=1', 'size=51200', process_input='y')
+        controller_exec_cmd_mock.assert_any_call(
+            'create', 'type=logicaldrive', 'drives=5I:1:3', 'raid=0',
             'size=51200', process_input='y')
 
     @mock.patch.object(objects.Controller, 'execute_cmd')
@@ -234,6 +300,74 @@ class ManagerTestCases(testtools.TestCase):
             'create', 'type=logicaldrive', 'drives=5I:1:3,5I:1:4,6I:1:5',
             'raid=5', process_input='y')
 
+    def test__sort_shared_logical_disks(self, get_all_details_mock):
+        logical_disk_sorted_expected = [
+            {'size_gb': 500, 'disk_type': 'hdd', 'raid_level': '1'},
+            {'share_physical_disks': True, 'size_gb': 450, 'disk_type': 'hdd',
+             'number_of_physical_disks': 6, 'raid_level': '0'},
+            {'share_physical_disks': True, 'size_gb': 200, 'disk_type': 'hdd',
+             'raid_level': '1+0'},
+            {'share_physical_disks': True, 'size_gb': 200, 'disk_type': 'hdd',
+             'raid_level': '0'},
+            {'share_physical_disks': True, 'size_gb': 100, 'disk_type': 'hdd',
+             'raid_level': '0'}]
+        logical_disks = [{'size_gb': 500,
+                          'disk_type': 'hdd',
+                          'raid_level': '1'},
+                         {'share_physical_disks': True,
+                          'size_gb': 450,
+                          'disk_type': 'hdd',
+                          'number_of_physical_disks': 6,
+                          'raid_level': '0'},
+                         {'share_physical_disks': True,
+                          'size_gb': 200,
+                          'disk_type': 'hdd',
+                          'raid_level': '1+0'},
+                         {'share_physical_disks': True,
+                          'size_gb': 200,
+                          'disk_type': 'hdd',
+                          'raid_level': '0'},
+                         {'share_physical_disks': True,
+                          'size_gb': 100,
+                          'disk_type': 'hdd',
+                          'raid_level': '0'}]
+        logical_disks_sorted = manager._sort_shared_logical_disks(
+            logical_disks)
+        self.assertEqual(logical_disks_sorted, logical_disk_sorted_expected)
+
+    def test__sort_shared_logical_disks_raid10(self, get_all_details_mock):
+        logical_disk_sorted_expected = [
+            {'size_gb': 600, 'disk_type': 'hdd', 'raid_level': '1'},
+            {'share_physical_disks': False, 'size_gb': 400, 'disk_type': 'hdd',
+             'raid_level': '1+0'},
+            {'share_physical_disks': False, 'size_gb': 100, 'disk_type': 'hdd',
+             'raid_level': '5'},
+            {'share_physical_disks': True, 'size_gb': 550, 'disk_type': 'hdd',
+             'raid_level': '1'},
+            {'share_physical_disks': True, 'size_gb': 200, 'disk_type': 'hdd',
+             'raid_level': '1+0'},
+            {'share_physical_disks': True, 'size_gb': 450, 'disk_type': 'hdd',
+             'number_of_physical_disks': 5, 'raid_level': '0'},
+            {'share_physical_disks': True, 'size_gb': 300, 'disk_type': 'hdd',
+             'raid_level': '5'}]
+        logical_disks = [
+            {'size_gb': 600, 'disk_type': 'hdd', 'raid_level': '1'},
+            {'share_physical_disks': True, 'size_gb': 550, 'disk_type': 'hdd',
+             'raid_level': '1'},
+            {'share_physical_disks': True, 'size_gb': 450, 'disk_type': 'hdd',
+             'number_of_physical_disks': 5, 'raid_level': '0'},
+            {'share_physical_disks': False, 'size_gb': 400, 'disk_type': 'hdd',
+             'raid_level': '1+0'},
+            {'share_physical_disks': True, 'size_gb': 300, 'disk_type': 'hdd',
+             'raid_level': '5'},
+            {'share_physical_disks': True, 'size_gb': 200, 'disk_type': 'hdd',
+             'raid_level': '1+0'},
+            {'share_physical_disks': False, 'size_gb': 100, 'disk_type': 'hdd',
+             'raid_level': '5'}]
+        logical_disks_sorted = manager._sort_shared_logical_disks(
+            logical_disks)
+        self.assertEqual(logical_disks_sorted, logical_disk_sorted_expected)
+
     @mock.patch.object(manager, 'get_configuration')
     @mock.patch.object(objects.Controller, 'execute_cmd')
     def test_delete_configuration(self, controller_exec_cmd_mock,
@@ -265,6 +399,19 @@ class ManagerTestCases(testtools.TestCase):
         get_configuration_mock.assert_called_once_with()
         self.assertEqual('foo', ret)
 
+    @mock.patch.object(manager, 'get_configuration')
+    def test_delete_configuration_hba_enabled(self, get_configuration,
+                                              get_all_details_mock):
+        drives = raid_constants.HPSSA_HBA_MODE
+        get_all_details_mock.return_value = drives
+
+        msg = ("An error was encountered while doing hpssa configuration: None"
+               " of the available HPSSA controllers Smart Array P822 in "
+               "Slot 3 have RAID enabled")
+        ex = self.assertRaises(exception.HPSSAOperationError,
+                               manager.delete_configuration)
+        self.assertIn(msg, str(ex))
+
     def test_get_configuration(self, get_all_details_mock):
 
         get_all_details_mock.return_value = raid_constants.HPSSA_ONE_DRIVE
@@ -307,17 +454,44 @@ class ManagerTestCases(testtools.TestCase):
         self.assertEqual(sorted(pds_active_expected), sorted(pds_active))
         self.assertEqual(sorted(pds_ready_expected), sorted(pds_ready))
 
+    def test__filter_raid_mode_controllers_hba(self, get_all_details_mock):
+        get_all_details_mock.return_value = raid_constants.HPSSA_HBA_MODE
+
+        server = objects.Server()
+
+        msg = ("An error was encountered while doing hpssa configuration: None"
+               " of the available HPSSA controllers Smart Array P822 in "
+               "Slot 3 have RAID enabled")
+        ex = self.assertRaises(exception.HPSSAOperationError,
+                               manager._filter_raid_mode_controllers,
+                               server)
+        self.assertIn(msg, str(ex))
+
+    def test__filter_raid_mode_controllers(self, get_all_details_mock):
+        get_all_details_mock.return_value = raid_constants.HPSSA_NO_DRIVES
+
+        server = objects.Server()
+        ctrl_expected = server.controllers
+
+        manager._filter_raid_mode_controllers(server)
+        self.assertEqual(ctrl_expected, server.controllers)
+
 
 class RaidConfigValidationTestCases(testtools.TestCase):
 
     def test_validate_fails_min_disks_number(self):
-        raid_config = {'size_gb': 100, 'raid_level': 5,
-                       'number_of_physical_disks': 2}
-        self.assertRaises(exception.InvalidInputError,
-                          manager.validate, raid_config)
+        raid_config = {'logical_disks':
+                       [{'size_gb': 100,
+                         'raid_level': '5',
+                         'number_of_physical_disks': 2}]}
+        msg = "RAID level 5 requires at least 3 disks"
+        self.assertRaisesRegex(exception.InvalidInputError, msg,
+                               manager.validate, raid_config)
 
     def test_validate_fails_min_physical_disks(self):
-        raid_config = {'size_gb': 100, 'raid_level': 5,
-                       'physical_disks': ['foo']}
-        self.assertRaises(exception.InvalidInputError,
-                          manager.validate, raid_config)
+        raid_config = {'logical_disks':
+                       [{'size_gb': 100, 'raid_level': '5',
+                         'physical_disks': ['foo']}]}
+        msg = "RAID level 5 requires at least 3 disks"
+        self.assertRaisesRegex(exception.InvalidInputError, msg,
+                               manager.validate, raid_config)
