@@ -61,6 +61,8 @@ class MaskedRequestDataTestCase(unittest.TestCase):
         self.assertIn(xml_data, str(self.maskedRequestData))
 
 
+@mock.patch.object(ribcl.RIBCLOperations, 'get_product_name',
+                   lambda x: 'ProLiant DL580 Gen8')
 class IloRibclTestCaseInitTestCase(unittest.TestCase):
 
     @mock.patch.object(urllib3, 'disable_warnings')
@@ -94,7 +96,21 @@ class IloRibclTestCase(unittest.TestCase):
 
     def setUp(self):
         super(IloRibclTestCase, self).setUp()
-        self.ilo = ribcl.RIBCLOperations("x.x.x.x", "admin", "Admin", 60, 443)
+        self.ilo = ribcl.RIBCLOperations("x.x.x.x", "admin",
+                                         "Admin", 60, 443)
+        self.ilo.init_model_based_tags('ProLiant DL580 Gen8')
+
+    def test_init_model_based_tags_gen7(self):
+        self.ilo.init_model_based_tags('Proliant DL380 G7')
+        self.assertEqual(self.ilo.MEMORY_SIZE_TAG, "MEMORY_SIZE")
+        self.assertEqual(self.ilo.MEMORY_SIZE_NOT_PRESENT_TAG, "Not Installed")
+        self.assertEqual(self.ilo.NIC_INFORMATION_TAG, "NIC_INFOMATION")
+
+    def test_init_model_based_tags(self):
+        self.ilo.init_model_based_tags('ProLiant DL580 Gen8')
+        self.assertEqual(self.ilo.MEMORY_SIZE_TAG, "TOTAL_MEMORY_SIZE")
+        self.assertEqual(self.ilo.MEMORY_SIZE_NOT_PRESENT_TAG, "N/A")
+        self.assertEqual(self.ilo.NIC_INFORMATION_TAG, "NIC_INFORMATION")
 
     @mock.patch.object(ribcl.RIBCLOperations, '_serialize_xml')
     @mock.patch.object(requests, 'post')
@@ -107,7 +123,7 @@ class IloRibclTestCase(unittest.TestCase):
 
         post_mock.assert_called_once_with(
             'https://x.x.x.x:443/ribcl',
-            headers={"Content-length": 14},
+            headers={"Content-length": '14'},
             data='serialized-xml',
             verify=False)
         response_mock.raise_for_status.assert_called_once_with()
@@ -127,7 +143,7 @@ class IloRibclTestCase(unittest.TestCase):
 
         post_mock.assert_called_once_with(
             'https://x.x.x.x:443/ribcl',
-            headers={"Content-length": 14},
+            headers={"Content-length": '14'},
             data='serialized-xml',
             verify='/somepath')
         response_mock.raise_for_status.assert_called_once_with()
@@ -145,7 +161,7 @@ class IloRibclTestCase(unittest.TestCase):
 
         post_mock.assert_called_once_with(
             'https://x.x.x.x:443/ribcl',
-            headers={"Content-length": 14},
+            headers={"Content-length": '14'},
             data='serialized-xml',
             verify=False)
 
@@ -528,13 +544,39 @@ class IloRibclTestCase(unittest.TestCase):
                           json_data)
 
     def test__parse_memory_embedded_health(self):
+        self.ilo.init_model_based_tags('Proliant DL580 Gen8')
         data = constants.GET_EMBEDDED_HEALTH_OUTPUT
         json_data = json.loads(data)
         memory_mb = self.ilo._parse_memory_embedded_health(json_data)
         self.assertEqual('32768', str(memory_mb))
         self.assertTrue(type(memory_mb), int)
 
+    def test__parse_memory_embedded_health_gen7(self):
+        self.ilo.model = 'Proliant DL380 G7'
+        self.ilo.init_model_based_tags('Proliant DL380 G7')
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT_GEN7
+        json_data = json.loads(data)
+        memory_mb = self.ilo._parse_memory_embedded_health(json_data)
+        self.assertEqual('32768', str(memory_mb))
+        self.assertTrue(type(memory_mb), int)
+
+    def test__parse_nics_embedded_health_gen7(self):
+        self.ilo.model = 'Proliant DL380 G7'
+        self.ilo.init_model_based_tags('Proliant DL380 G7')
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT_GEN7
+        json_data = json.loads(data)
+        expected_output = {u'Port 4': u'78:ac:c0:fe:49:66',
+                           u'Port 3': u'78:ac:c0:fe:49:64',
+                           u'Port 2': u'78:ac:c0:fe:49:62',
+                           u'Port 1': u'78:ac:c0:fe:49:60'}
+        nic_data = self.ilo._parse_nics_embedded_health(json_data)
+        self.assertIsInstance(nic_data, dict)
+        for key, val in nic_data.items():
+            self.assertIn("Port", key)
+        self.assertEqual(expected_output, nic_data)
+
     def test__parse_nics_embedded_health(self):
+        self.ilo.init_model_based_tags('Proliant DL580 Gen8')
         data = constants.GET_EMBEDDED_HEALTH_OUTPUT
         json_data = json.loads(data)
         expected_output = {u'Port 4': u'40:a8:f0:1e:86:77',
@@ -827,6 +869,45 @@ class IloRibclTestCase(unittest.TestCase):
                           'raw_fw_file.bin',
                           'invalid_component')
 
+    def test__get_memory_details_value_based_on_model_gen7(self):
+        self.ilo.model = 'Proliant DL380 G7'
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT_GEN7
+        self.assertIn('MEMORY_COMPONENTS', data)
+        self.assertIn('MEMORY_COMPONENT', data)
+
+    def test__get_memory_details_value_based_on_model(self):
+        self.ilo.model = 'ProLiant DL580 Gen8'
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT
+        self.assertIn('MEMORY_DETAILS_SUMMARY', data)
+
+    def test__update_nic_data_from_nic_info_based_on_model_gen7(self):
+        self.ilo.model = 'Proliant DL380 G7'
+        nic_dict = {}
+        item = {'NETWORK_PORT': {'VALUE': 'Port 1'},
+                'MAC_ADDRESS': {'VALUE': '78:ac:c0:fe:49:60'}}
+        port = 'Port 1'
+        mac = '78:ac:c0:fe:49:60'
+        expected_result = {'Port 1': '78:ac:c0:fe:49:60'}
+        self.ilo._update_nic_data_from_nic_info_based_on_model(
+            nic_dict, item, port, mac)
+        self.assertEqual(expected_result, nic_dict)
+
+    def test__update_nic_data_from_nic_info_based_on_model(self):
+        self.ilo.model = 'ProLiant DL580 Gen8'
+        nic_dict = {}
+        item = {'NETWORK_PORT': {'VALUE': 'Port 1'},
+                'STATUS': {'VALUE': 'Unknown'},
+                'PORT_DESCRIPTION': {'VALUE': 'N/A'},
+                'LOCATION': {'VALUE': 'Embedded'},
+                'MAC_ADDRESS': {'VALUE': '40:a8:f0:1e:86:74'},
+                'IP_ADDRESS': {'VALUE': 'N/A'}}
+        port = 'Port 1'
+        mac = '40:a8:f0:1e:86:74'
+        expected_result = {'Port 1': '40:a8:f0:1e:86:74'}
+        self.ilo._update_nic_data_from_nic_info_based_on_model(
+            nic_dict, item, port, mac)
+        self.assertEqual(expected_result, nic_dict)
+
 
 class IloRibclTestCaseBeforeRisSupport(unittest.TestCase):
 
